@@ -1,5 +1,5 @@
 import boto3
-from SingletonMeta import SingletonMeta
+from basacommons.SingletonMeta import SingletonMeta
 
 class AlertManager(metaclass = SingletonMeta):
 
